History
=======

0.0.4 (2014-04-17)
------------------

* 'group' API now operational outside of a context manager.
* Minor code changes.

0.0.3 (2014-04-14)
------------------

* Introduced the 'group' API.

0.0.2 (2014-04-14)
------------------

* Added more documentation for simple usage.
* Worked on installation utilities.
* Still no tests :(.

0.0.1 (2014-04-14)
------------------

* Initial release.
